@@ -5,6 +5,7 @@
 #' [Units of Information](https://en.wikipedia.org/wiki/Units_of_information)
 #' on Wikipedia for more details.
 #'
+#' @inherit label_number return
 #' @param units Unit to use. Should either one of:
 #'   * "kB", "MB", "GB", "TB", "PB", "EB", "ZB", and "YB" for
 #'     SI units (base 1000).
@@ -14,8 +15,7 @@
 #'     unit for each value.
 #' @inheritParams number_format
 #' @inheritDotParams number
-#' @return A labeller function that takes a numeric vector of breaks and
-#'   returns a character vector of labels.
+#'
 #' @export
 #' @family labels for continuous scales
 #' @family labels for log scales
@@ -37,9 +37,7 @@
 #'   labels = label_bytes("auto_binary")
 #' )
 label_bytes <- function(units = "auto_si", accuracy = 1, scale = 1, ...) {
-  if (!(is.character(units) && length(units) == 1)) {
-    cli::cli_abort("{.arg units} must be a scalar string")
-  }
+  check_string(units)
   force_all(accuracy, ...)
 
   function(x) {
@@ -51,14 +49,13 @@ label_bytes <- function(units = "auto_si", accuracy = 1, scale = 1, ...) {
       si_units <- paste0(names(powers), "B")
       bin_units <- paste0(names(powers), "iB")
 
+      arg_match0(units, c(si_units, bin_units))
       if (units %in% si_units) {
         base <- 1000
         power <- powers[[match(units, si_units)]]
-      } else if (units %in% bin_units) {
+      } else {
         base <- 1024
         power <- powers[[match(units, bin_units)]]
-      } else {
-        cli::cli_abort("{.val {units}} is not a valid unit")
       }
 
       suffix <- paste0(" ", units)
