@@ -4,10 +4,7 @@
 #' `label_math()` constructs expressions by replacing the pronoun `.x`
 #' with each string.
 #'
-#' @section Old interface:
-#' `parse_format()` and `math_format()` was retired; please use
-#' `label_parse()` and `label_math()` instead.
-#' @inherit number_format return
+#' @inherit label_number return
 #' @seealso [plotmath] for the details of mathematical formatting in R.
 #' @export
 #' @family labels for continuous scales
@@ -21,18 +18,10 @@
 #' # Use label_math() with continuous scales
 #' demo_continuous(c(1, 5))
 #' demo_continuous(c(1, 5), labels = label_math(alpha[.x]))
+#' demo_continuous(c(1, 5), labels = label_math())
 label_parse <- function() {
-  # From ggplot2:::parse_safe
-  # See https://github.com/tidyverse/ggplot2/issues/2864 for discussion.
   function(text) {
-    text <- as.character(text)
-
-    out <- vector("expression", length(text))
-    for (i in seq_along(text)) {
-      expr <- parse(text = text[[i]])
-      out[[i]] <- if (length(expr) == 0) NA else expr[[1]]
-    }
-    out
+    parse_safe(as.character(text))
   }
 }
 
@@ -62,9 +51,30 @@ label_math <- function(expr = 10^.x, format = force) {
   }
 }
 
-#' @rdname label_parse
+#' Superseded interface to `label_parse()`/`label_math()`
+#'
+#' @description
+#' `r lifecycle::badge("superseded")`
+#'
+#' These functions are kept for backward compatibility; you should switch
+#' to [label_parse()]/[label_math()] for new code.
+#'
+#' @keywords internal
 #' @export
+#' @inheritParams label_parse
 parse_format <- label_parse
-#' @rdname label_parse
+#' @rdname parse_format
 #' @export
 math_format <- label_math
+
+
+# From ggplot2:::parse_safe
+# See https://github.com/tidyverse/ggplot2/issues/2864 for discussion.
+parse_safe <- function(text) {
+  out <- vector("expression", length(text))
+  for (i in seq_along(text)) {
+    expr <- parse(text = text[[i]])
+    out[[i]] <- if (length(expr) == 0) NA else expr[[1]]
+  }
+  out
+}
