@@ -14,9 +14,16 @@
 #'   suffix = " %"
 #' )
 #' demo_continuous(c(0, .01), labels = french_percent)
-label_percent <- function(accuracy = NULL, scale = 100, prefix = "",
-                          suffix = "%", big.mark = " ", decimal.mark = ".",
-                          trim = TRUE, ...) {
+label_percent <- function(
+  accuracy = NULL,
+  scale = 100,
+  prefix = "",
+  suffix = "%",
+  big.mark = NULL,
+  decimal.mark = NULL,
+  trim = TRUE,
+  ...
+) {
   number_format(
     accuracy = accuracy,
     scale = scale,
@@ -44,9 +51,17 @@ percent_format <- label_percent
 
 #' @export
 #' @rdname percent_format
-percent <- function(x, accuracy = NULL, scale = 100, prefix = "",
-                    suffix = "%", big.mark = " ", decimal.mark = ".",
-                    trim = TRUE, ...) {
+percent <- function(
+  x,
+  accuracy = NULL,
+  scale = 100,
+  prefix = "",
+  suffix = "%",
+  big.mark = NULL,
+  decimal.mark = NULL,
+  trim = TRUE,
+  ...
+) {
   number(
     x = x,
     accuracy = accuracy,
