@@ -4,8 +4,8 @@
 #'
 #' @inherit label_number return params
 #' @param prefix A character vector of length 3 giving the prefixes to
-#'   put in front of numbers. The default values are `c("<", "", ">")`
-#'   if `add_p` is `TRUE` and `c("p<", "p=", "p>")` if `FALSE`.
+#'   put in front of numbers. The default values are `c("p<", "p=", "p>")`
+#'   if `add_p` is `TRUE` and `c("<", "", ">")` if `FALSE`.
 #' @param add_p Add "p=" before the value?
 #' @export
 #' @family labels for continuous scales
@@ -18,7 +18,12 @@
 #' # Or provide your own prefixes
 #' prefix <- c("p < ", "p = ", "p > ")
 #' demo_continuous(c(0, 1), labels = label_pvalue(prefix = prefix))
-label_pvalue <- function(accuracy = .001, decimal.mark = ".", prefix = NULL, add_p = FALSE) {
+label_pvalue <- function(
+  accuracy = .001,
+  decimal.mark = NULL,
+  prefix = NULL,
+  add_p = FALSE
+) {
   force_all(accuracy, decimal.mark, add_p)
   function(x) {
     pvalue(
@@ -47,11 +52,15 @@ pvalue_format <- label_pvalue
 
 #' @rdname pvalue_format
 #' @export
-pvalue <- function(x,
-                   accuracy = .001,
-                   decimal.mark = ".",
-                   prefix = NULL,
-                   add_p = FALSE) {
+pvalue <- function(
+  x,
+  accuracy = .001,
+  decimal.mark = NULL,
+  prefix = NULL,
+  add_p = FALSE
+) {
+  decimal.mark <- decimal.mark %||%
+    getOption("scales.decimal.mark", default = ".")
   out <- number(x, accuracy, decimal.mark = decimal.mark)
   below <- number(accuracy, accuracy, decimal.mark = decimal.mark)
   above <- number(1 - accuracy, accuracy, decimal.mark = decimal.mark)
