@@ -8,19 +8,16 @@
 #'   show_col(pal_dichromat("BluetoOrange.10")(10))
 #'   show_col(pal_dichromat("BluetoOrange.10")(5))
 #'
-#'   # Can use with gradient_n to create a continous gradient
+#'   # Can use with gradient_n to create a continuous gradient
 #'   cols <- pal_dichromat("DarkRedtoBlue.12")(12)
 #'   show_col(pal_gradient_n(cols)(seq(0, 1, length.out = 30)))
 #' }
 pal_dichromat <- function(name) {
   check_installed("dichromat")
-
-  if (!any(name == names(dichromat::colorschemes))) {
-    cli::cli_abort("Palette name must be one of {.or {.val {names(dichromat::colorschemes)}}}")
-  }
-
+  arg_match0(name, names(dichromat::colorschemes))
   pal <- dichromat::colorschemes[[name]]
-  function(n) pal[seq_len(n)]
+
+  pal_manual(pal, type = "colour")
 }
 
 #' @export
