@@ -4,12 +4,15 @@
 #' make it possible to build up complete ranges with multiple passes.
 #'
 #' @export
-Range <- R6::R6Class("Range", list(
-  range = NULL,
-  initialize = function() {
-    self$range <- NULL
-  }
-))
+Range <- R6::R6Class(
+  "Range",
+  list(
+    range = NULL,
+    initialize = function() {
+      self$range <- NULL
+    }
+  )
+)
 
 #' @export
 #' @rdname Range
@@ -18,9 +21,16 @@ DiscreteRange <- R6::R6Class(
   inherit = Range,
   list(
     factor = NULL,
-    train = function(x, drop = FALSE, na.rm = FALSE) {
+    train = function(x, drop = FALSE, na.rm = FALSE, call = caller_env()) {
       self$factor <- self$factor %||% is.factor(x)
-      self$range <- train_discrete(x, self$range, drop, na.rm, self$factor)
+      self$range <- train_discrete(
+        x,
+        self$range,
+        drop,
+        na.rm,
+        self$factor,
+        call = call
+      )
     },
     reset = function() {
       self$range <- NULL
@@ -35,7 +45,9 @@ ContinuousRange <- R6::R6Class(
   "ContinuousRange",
   inherit = Range,
   list(
-    train = function(x) self$range <- train_continuous(x, self$range),
+    train = function(x, call = caller_env()) {
+      self$range <- train_continuous(x, self$range, call = call)
+    },
     reset = function() self$range <- NULL
   )
 )
